@@ -2,6 +2,7 @@
 #
 # Copyright (c) 2015-2020 ODC Contributors
 # SPDX-License-Identifier: Apache-2.0
+import importlib
 import itertools
 import math
 from collections import OrderedDict, namedtuple
@@ -415,16 +416,18 @@ class GeoBox:
         """GeoBox bounding box in the native CRS."""
         return BoundingBox.from_transform(self._shape, self._affine, crs=self._crs)
 
-    def map_bounds(
-        self, *args, **kw
-    ) -> Tuple[Tuple[float, float], Tuple[float, float]]:
+    def map_bounds(self) -> Tuple[Tuple[float, float], Tuple[float, float]]:
         """
         Query bounds in folium/ipyleaflet style.
 
         Returns SW, and NE corners in lat/lon order.
         ``((lat_w, lon_s), (lat_e, lon_n))``.
         """
-        return self.boundingbox.map_bounds(*args, **kw)
+        if self._crs is not None:
+            (x0, y0), _, (x1, y1) = self.extent.exterior.to_crs("epsg:4326").points[:3]
+        else:
+            (x0, y0), _, (x1, y1) = self.extent.exterior.points[:3]
+        return (y0, x0), (y1, x1)
 
     def _reproject_resolution(self, npoints: int = 100):
         bbox = self.extent.boundingbox
@@ -482,7 +485,7 @@ class GeoBox:
             buffer = buffer * max(*self.resolution.xy)
             ext = ext.buffer(buffer)
 
-        return ext.to_crs(crs, resolution=self._reproject_resolution(npoints))
+        return ext.to_crs(crs, resolution=self._reproject_resolution(npoints)).dropna()
 
     @property
     def geographic_extent(self) -> Geometry:
@@ -707,6 +710,27 @@ class GeoBox:
         """
         return self[self.shape.map(lambda x: x // 2).yx]
 
+    @property
+    def compat(self):
+        """
+        Convert to :py:class:`datacube.utils.geometry.GeoBox`
+        """
+        try:
+            geom = importlib.import_module("datacube.utils.geometry")
+        except ModuleNotFoundError:
+            return None
+
+        w, h = self.shape.wh
+        return geom.GeoBox(w, h, self._affine, str(self._crs))
+
+    def __dask_tokenize__(self):
+        return (
+            "odc.geo.geobox.GeoBox",
+            str(self.crs),
+            *self._shape.yx,
+            *self._affine[:6],
+        )
+
     def svg(
         self,
         scale_factor: float = 1.0,
@@ -762,7 +786,7 @@ class GeoBox:
 
         dx, dy = self._affine * (step, 0)
         res = math.sqrt(dx * dx + dy * dy) / 5
-        return lines.to_crs("epsg:4326", resolution=res)
+        return lines.to_crs("epsg:4326", resolution=res).dropna()
 
     def outline(self, mode: OutlineMode = "native", notch: float = 0.1) -> Geometry:
         """
@@ -814,7 +838,7 @@ class GeoBox:
         bbox = native.boundingbox
         res = max(bbox.span_x, bbox.span_y) / 100
 
-        return native.to_crs("EPSG:4326", resolution=res)
+        return native.to_crs("EPSG:4326", resolution=res).dropna()
 
     def _display_bbox(self, pad_fraction: float = 0.1):
         bbox = self.geographic_extent.boundingbox
@@ -851,24 +875,27 @@ class GeoBox:
 
         crs = self._crs
         if crs is None:
-            epsg = "not set"
+            authority = ("", "")
             wkt = "not set"
             units = ""
             svg_global_txt = ""
         else:
-            epsg = "undefined" if crs.epsg is None else f"{crs.epsg:d}"
+            authority = crs.authority
             wkt = crs.to_wkt(pretty=True).replace("\n", "<br/>").replace(" ", "&nbsp;")
             units = crs.units[0]
             svg_global_txt = svg_base_map(
                 sz=200, target=self.geographic_extent.centroid.coords[0]
             )
 
+        if authority == ("", ""):
+            authority = ("CRS", "WKT")
+
         units = norm_units(units)
         pix_sz = max(*self.resolution.map(abs).xy)
 
         info = [
             ("Dimensions", f"{W:,d}x{H:,d}"),
-            ("EPSG", f"{epsg}"),
+            authority,
             ("Resolution", f"{pix_sz:g}{units}"),
             ("Cell", f"{grid_step:,d}px"),
         ]
@@ -1181,3 +1208,10 @@ class GeoboxTiles:
             gbox = self[idx]
             if gbox.extent.intersects(poly):
                 yield idx
+
+    def __dask_tokenize__(self):
+        return (
+            "odc.geo.geobox.GeoboxTiles",
+            *self._tiles.shape.yx,
+            *self._gbox.__dask_tokenize__()[1:],
+        )
