@@ -6,8 +6,20 @@ import array
 import functools
 import itertools
 import math
+import warnings
 from collections import abc
-from typing import Any, Dict, Iterable, Iterator, List, Optional, Sequence, Tuple, Union
+from typing import (
+    Any,
+    Callable,
+    Dict,
+    Iterable,
+    Iterator,
+    List,
+    Optional,
+    Sequence,
+    Tuple,
+    Union,
+)
 
 import numpy
 from affine import Affine
@@ -15,7 +27,7 @@ from shapely import geometry, ops
 from shapely.geometry import base
 
 from .crs import CRS, CRSMismatchError, MaybeCRS, SomeCRS, norm_crs, norm_crs_or_error
-from .types import SomeShape, shape_
+from .types import SomeShape, SupportsCoords, shape_
 
 CoordList = List[Tuple[float, float]]
 
@@ -175,10 +187,10 @@ class BoundingBox(Sequence[float]):
         Returns SW, and NE corners in lat/lon order.
         ``((lat_w, lon_s), (lat_e, lon_n))``.
         """
+        x0, y0, x1, y1 = self._box
         if self._crs == "epsg:4326" or self._crs is None:
-            x0, y0, x1, y1 = self._box
             return (y0, x0), (y1, x1)
-        x0, y0, x1, y1 = self.to_crs("epsg:4326")
+        (x0, y0), _, (x1, y1) = self.polygon.exterior.to_crs("epsg:4326").points[:3]
         return (y0, x0), (y1, x1)
 
     @property
@@ -300,7 +312,7 @@ def _clone_shapely_geom(geom: base.BaseGeometry) -> base.BaseGeometry:
     return type(geom)(geom)
 
 
-class Geometry:
+class Geometry(SupportsCoords[float]):
     """
     2D Geometry with CRS.
 
@@ -408,8 +420,6 @@ class Geometry:
     @property
     def wkt(self) -> str: return self.geom.wkt
     @property
-    def __array_interface__(self): return self.geom.__array_interface__
-    @property
     def __geo_interface__(self): return self.geom.__geo_interface__
     # fmt: on
 
@@ -585,11 +595,19 @@ class Geometry:
         for g in ops.split(self.geom, splitter.geom).geoms:
             yield Geometry(g, self.crs)
 
-    def __iter__(self) -> Iterator["Geometry"]:
+    @property
+    def geoms(self) -> Iterator["Geometry"]:
         sub_geoms = getattr(self.geom, "geoms", [])
         for geom in sub_geoms:
             yield Geometry(geom, self.crs)
 
+    def __iter__(self) -> Iterator["Geometry"]:
+        warnings.warn(
+            "Iteration interface is deprecated, please use `.geoms`",
+            category=DeprecationWarning,
+        )
+        yield from self.geoms
+
     def __nonzero__(self) -> bool:
         return not self.is_empty
 
@@ -649,7 +667,7 @@ class Geometry:
             )
 
         if self.is_multi:
-            return "".join([g.svg_path(ndecimal) for g in self])
+            return "".join([g.svg_path(ndecimal) for g in self.geoms])
 
         if self.type == "Polygon":
             return "".join(
@@ -658,6 +676,45 @@ class Geometry:
 
         return render_ring(self, close=self.is_ring)
 
+    def filter(self, pred: Callable[[float, float], bool]) -> "Geometry":
+        """
+        Keep only those points for which `pred(x,y) is True`.
+        """
+
+        if self.type == "Polygon":
+            # TODO: deal with interior rings
+            pts = [(x, y) for x, y in self.exterior.points if pred(x, y)]
+            return polygon(pts, self.crs)
+
+        if self.type in ("LinearRing", "LineString"):
+            pts = [(x, y) for x, y in self.points if pred(x, y)]
+            _geom = type(self.geom)(pts)
+            return Geometry(_geom, self.crs)
+
+        if self.type == "Point":
+            x, y = self.coords[0]
+            if pred(x, y):
+                return self
+            return Geometry(geometry.Point(), self.crs)
+
+        if self.type == "MultiPoint":
+            pts = [(x, y) for x, y in [pt.points[0] for pt in self.geoms] if pred(x, y)]
+            return multipoint(pts, self.crs)
+
+        if self.is_multi:
+            _filtered = [g.filter(pred).geom for g in self.geoms]
+            _filtered = [g for g in _filtered if not g.is_empty]
+            _geom = type(self.geom)(_filtered)
+            return Geometry(_geom, self.crs)
+
+        raise AssertionError("Unhandled geometry type detected")  # pragma: no cover
+
+    def dropna(self) -> "Geometry":
+        """
+        Only keep finite points.
+        """
+        return self.filter(lambda x, y: math.isfinite(x) and math.isfinite(y))
+
 
 def common_crs(geoms: Iterable[Geometry]) -> Optional[CRS]:
     """
@@ -737,7 +794,7 @@ def clip_lon180(geom: Geometry, tol=1e-6) -> Geometry:
         return _clip_180(xx, clip), yy
 
     if geom.type.startswith("Multi"):
-        return multigeom(g.transform(transformer) for g in geom)
+        return multigeom(g.transform(transformer) for g in geom.geoms)
 
     return geom.transform(transformer)
 
